<?php
namespace Pinpoint\Conesso\Helper;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\ScopeInterface;

class Config extends AbstractHelper
{
    const XML_PATH_IS_MODULE_ENABLED = 'basic_settings/settings/enabled';
    const XML_PATH_CONNECTION_TYPE = 'basic_settings/settings/connection';
    const XML_PATH_PRODUCTION_API_KEY = 'basic_settings/settings/production_api_key';
    const XML_PATH_TEST_API_KEY = 'basic_settings/settings/test_api_key';

    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * @param Context $context
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        Context $context,
        ScopeConfigInterface $scopeConfig
    ) {
        $this->scopeConfig = $scopeConfig;
        parent::__construct($context);
    }

    /**
     * Is module enabled
     * @return string
     */
    public function isModuleEnabled(): string
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_IS_MODULE_ENABLED,
            ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * Check is enable
     *
     * @return string
     */
    public function getConnectionType(): string
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_CONNECTION_TYPE,
            ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * @return mixed
     */
    public function getProductionApiKey(): mixed
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_PRODUCTION_API_KEY,
            ScopeInterface::SCOPE_STORE,
        );
    }

    /**
     * @return mixed
     */
    public function getTestApiKey(): mixed
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_TEST_API_KEY,
            ScopeInterface::SCOPE_STORE,
        );
    }
}
