<?php
namespace Pinpoint\Conesso\Model\Api\Management\Products;

use Magento\Catalog\Api\ProductRepositoryInterface;
use Pinpoint\Conesso\Api\Data\ProductSyncInterface;
use Pinpoint\Conesso\Api\Management\ProductManagementInterface;
use Pinpoint\Conesso\Api\Repository\ProductsSyncRepositoryInterface;
use Magento\Framework\Api\SearchCriteriaBuilder;
use Pinpoint\Conesso\Api\Transfer\RequestProviderInterface;
use Pinpoint\Conesso\Model\Api\Transfer\Request\ProductRequest;
use Psr\Log\LoggerInterface;

class ProcessProducts implements ProductManagementInterface
{
    private $productsSyncRepository;

    private $searchCriteriaBuilder;

    private $requestProvider;

    private $productRepository;
    private $logger;
    public function __construct(
        ProductsSyncRepositoryInterface $productsSyncRepository,
        SearchCriteriaBuilder $searchCriteriaBuilder,
        RequestProviderInterface $requestProvider,
        ProductRepositoryInterface $productRepository,
        LoggerInterface $logger
    ) {
        $this->productsSyncRepository = $productsSyncRepository;
        $this->searchCriteriaBuilder = $searchCriteriaBuilder;
        $this->requestProvider = $requestProvider;
        $this->productRepository = $productRepository;
        $this->logger = $logger;
    }

    public function processSyncProducts()
    {
        try {
            $items = $this->productsSyncRepository->getList($this->getSearchCriteria());
            foreach ($items as $item ) {
                $product = $this->getProductSku($item->getProductSku());
                if($this->getRequestProvider()->sendRequest(
                    ['item' => $product,'event_type' => $item->getEventType()]))
                {
                    $item->setIsSynced(1);
                    $this->productsSyncRepository->save($item);
                }
            }
        } catch(\Exception $e) {
            $this->logger->info(__($e->getMessage()));
        }

        return true;
    }

    public function migrateProducts()
    {
        $this->productsSyncRepository->deleteById(0);
    }

    private function getSearchCriteria()
    {
        return $this->searchCriteriaBuilder
            ->addFilter(ProductSyncInterface::IS_SYNCED, '0', 'eq')
            //->addFilter(ProductSyncInterface::STORE_ID, '1', 'eq')
            ->create()
            ->setPageSize(75);
    }

    private function getRequestProvider()
    {
        return $this->requestProvider->getRequestProvider(ProductRequest::class);
    }

    private function getProductSku($sku)
    {
        try {
            return $this->productRepository->get($sku);
        } catch (\Exception $e) {

        }
    }
}
